"use strict"

var DOMUtil = require('../utils/mp-dom-util.js');
var EventDispatcher = require('../event-dispatcher.js');
var Decorator = require('./mp-decorator.js');

// @class StateDecorator
//
// Decorates the node to be able to show a state of itself.
class StateDecorator extends Decorator {
    constructor(component, node, data) {
        super(component, node);
        this._state = data.state;
    }

    // Render the state of this node both in the Map and the Menu.
    //
    // @marker - Marker View of this node.
    // @menu - Menu View of this node.
    render(marker, menu) {
        this._component.render(marker, menu);

        this._renderMarker(marker);
        this._renderMenu(menu);
    }

    // Render the state color or name of this node.
    //
    // @marker - Marker View of this node.
    // @menu - Menu View of this node.
    // @data - Updated node data.
    update(marker, menu, data) {
        this._component.update(marker, menu, data);

        if(data !== undefined && this._state.color !== data.state.color) {
            this._state = data.state;
            this._updateMarker(marker);
            this._updateMenu(menu);
        }
    }

    // Nothing to remove in this component, but spread the call throught the
    // next component.
    remove() {
        this._component.remove();
    }

    // Return true if the component searched is the state one.
    hasComp(comp) {
        if(comp === 'state') return true;
        return this._component.hasComp(comp);
    }

    // Change this node icon color to the one specified by the server.
    //
    // @marker - Marker View of this node.
    _renderMarker(marker) {
        marker.addState(this._state);
    }

    // Change this node menu icon color to the one specified by the server.
    //
    // @menu - Menu View of this node.
    _renderMenu(menu) {
        menu.addState(this._state);
    }

    // Update this node icon color to the one specified by the server.
    //
    // @marker - Marker View of this node.
    _updateMarker(marker) {
        marker.state = this._state;
    }

    // Update this node menu icon color to the one specified by the server.
    //
    // @menu - Menu View of this node.
    _updateMenu(menu) {
        menu.state = this._state;
    }
}

module.exports = StateDecorator;
