"use strict"

var DOMUtil = require('../utils/mp-dom-util.js');
var EventDispatcher = require('../event-dispatcher.js');
var Decorator = require('./mp-decorator.js');

// @class TooltipDecorator
//
// Decorates the node with a tooltip under the marker position.
class TooltipDecorator extends Decorator {
    constructor(component, node, data) {
        super(component, node);

        this._tooltip = data.tooltip;
    }

    // Render the tooltip under the marker Map View Element.
    //
    // @marker - The node Marker View.
    // @menu - The node Menu View.
    render(marker, menu) {
        this._component.render(marker, menu);

        this._renderMarker(marker);
    }

    // Update the tooltip name when changed.
    //
    // @marker - The node Marker View.
    // @menu - The node Menu View.
    // @data - Node updated data.
    update(marker, menu, data) {
        this._component.update(marker, menu, data);

        if(data !== undefined && data.tooltip !== this._tooltip) {
            this._tooltip = data.tooltip;
            this._updateMarker();
        }
    }

    // Nothing to remove in this component, but spread the call throught the
    // next component.
    remove() {
        this._component.remove();
    }

    // Return true if the component searched is the tooltip one.
    hasComp(comp) {
        if(comp === 'tooltip') return true;
        return this._component.hasComp(comp);
    }

    // Create the tooltip Element and append it in the Marker View.
    _renderMarker(marker) {
        marker.addTooltip(this._tooltip);
    }

    // Update the tooltip name in the Marker View.
    _updateMarker(marker) {
        marker.tooltip = this._tooltip;
    }
}

module.exports = TooltipDecorator;
